CREDENTIALS_MISSING constant

ErrorReason const CREDENTIALS_MISSING

The request is denied because the request doesn't have any authentication credentials. For more information regarding the supported authentication strategies for Google Cloud APIs, see https://cloud.google.com/docs/authentication.

Example of an ErrorInfo when the request is to the Cloud Storage API without any authentication credentials.

{ "reason": "CREDENTIALS_MISSING",
  "domain": "googleapis.com",
  "metadata": {
    "service": "storage.googleapis.com",
    "method": "google.storage.v1.Storage.GetObject"
  }
}

Implementation

static const ErrorReason CREDENTIALS_MISSING =
    ErrorReason._(20, _omitEnumNames ? '' : 'CREDENTIALS_MISSING');