INPUT_ONLY constant

FieldBehavior const INPUT_ONLY

Denotes a field as input only. This indicates that the field is provided in requests, and the corresponding field is not included in output.

Implementation

static const FieldBehavior INPUT_ONLY =
    FieldBehavior._(4, _omitEnumNames ? '' : 'INPUT_ONLY');