OUTPUT_ONLY constant
FieldBehavior
const OUTPUT_ONLY
Denotes a field as output only. This indicates that the field is provided in responses, but including the field in a request does nothing (the server must ignore it and must not throw an error as a result of the field's presence).
Implementation
static const FieldBehavior OUTPUT_ONLY = FieldBehavior._(3, _omitEnumNames ? '' : 'OUTPUT_ONLY');