DECLARATIVE_FRIENDLY constant

ResourceDescriptor_Style const DECLARATIVE_FRIENDLY

This resource is intended to be "declarative-friendly".

Declarative-friendly resources must be more strictly consistent, and setting this to true communicates to tools that this resource should adhere to declarative-friendly expectations.

Note: This is used by the API linter (linter.aip.dev) to enable additional checks.

Implementation

static const ResourceDescriptor_Style DECLARATIVE_FRIENDLY =
    ResourceDescriptor_Style._(
        1, _omitEnumNames ? '' : 'DECLARATIVE_FRIENDLY');