copyWith method

  1. @Deprecated('See https://github.com/google/protobuf.dart/issues/998.')
OptionalGroup_extension_lite copyWith(
  1. void updates(
    1. OptionalGroup_extension_lite
    )
)

Apply updates to a copy of this message.

Makes a writable shallow copy of this message, applies the updates to it, and marks the copy read-only before returning it.

Implementation

@$core.Deprecated('See https://github.com/google/protobuf.dart/issues/998.')
OptionalGroup_extension_lite copyWith(
        void Function(OptionalGroup_extension_lite) updates) =>
    super.copyWith(
            (message) => updates(message as OptionalGroup_extension_lite))
        as OptionalGroup_extension_lite;